@@ -1,9 +1,9 @@
-from .parse import RawChunk
-from .chunks import Chunk, YAMLChunk, YAMLDataChunk, MarkdownChunk, HTMLChunk
 from .build_html import build_html
-from .build_latex import build_latex, build_latex_yaml
+from .build_latex import build_latex
+from .chunks import Chunk, HTMLChunk, MarkdownChunk, YAMLChunk, YAMLDataChunk
+from .parse import RawChunk
 
-__version__ = "0.2.2"
+__version__ = "0.2.3"
 
 __all__ = [
     "RawChunk",
