@@ -15,21 +15,22 @@ from .figure import Figure
 from .hint import Hint
 from .lines import Lines
 from .parse import ParserState, _parse
+from .report import Report, print_reports
 from .table import Table
-from .tell import tell
 from .video import Video
 
 
-def write_file(html, target_file_path):
+def write_file(html, target_file_path, report):
     encoding = "utf-8"
     try:
         with open(target_file_path, "w", encoding=encoding) as html_file:
             html_file.write(html)
     except UnicodeEncodeError as error:
-        tell("Encoding error when writing file {}.".format(target_file_path))
-        character = error.object[error.start : error.end]
+        report.tell("Encoding error when writing file {}.".format(target_file_path))
+        text = error.object
+        character = text[error.start : error.end]
         line = html.count("\n", 0, error.start) + 1
-        tell(
+        report.tell(
             "Character {} in line {} cannot be saved with encoding {}.".format(
                 character, line, encoding
             )
@@ -46,16 +47,16 @@ def default_html_template():
     return "\n".join(html)
 
 
-def load_html_template(template_path):
+def load_html_template(template_path, report):
     try:
         with open(
             template_path, "r", encoding="utf-8", errors="surrogateescape"
         ) as templatefile:
             template = templatefile.read()
-            tell("Loading template {}.".format(template_path), "info")
+            report.tell("Loading template {}.".format(template_path), Report.INFO)
             return template
     except FileNotFoundError:
-        tell(
+        report.tell(
             "Template file missing. Expected at {}. Using default template.".format(
                 template_path
             ),
@@ -64,26 +65,6 @@ def load_html_template(template_path):
     return default_html_template()
 
 
-def build_latex(input_path, output_path, template_file, verbose=False):
-    # global LOG_VERBOSE
-    LOG_VERBOSE = verbose
-    template = load_html_template(template_file)
-    latex = []
-    latex.append(load_html_template(template_file))
-    for filename in os.listdir(input_path):
-        source_file_path = os.path.join(input_path, filename)
-        if os.path.isfile(source_file_path) and filename.endswith(".md"):
-            with open(source_file_path, "r", encoding="utf-8") as file:
-                lines = file.readlines()
-                tell("{}".format(source_file_path), "info")
-                latex.append(transform_page_to_latex(lines, source_file_path, False))
-                latex.append("\\clearpage\\newpage")
-    latex.append("\end{document}")
-    latex = "\n".join(latex)
-    target_file_path = os.path.join(output_path, "output.tex")
-    write_file(latex, target_file_path)
-
-
 class Builder:
     def __init__(self, yaml, base_path):
         self.yaml = yaml
@@ -94,30 +75,34 @@ class Builder:
         )
 
     def to_latex(self):
+        reports = []
+        report = Report(None)
         latex = []
-        latex.append(load_html_template(self.template_file))
+        latex.append(load_html_template(self.template_file, report))
         for element in self.yaml["content"]:
             if element["type"] == "chapter":
-                latex.append("\chapter{{{}}}".format(element["name"]))
+                latex.append(r"\chapter{{{}}}".format(element["name"]))
                 for doc in element["content"]:
                     source_file_path = self.base_path / "pages" / doc
                     if source_file_path.is_file() and source_file_path.exists():
                         with open(source_file_path, "r", encoding="utf-8") as file:
+                            file_report = Report(source_file_path)
+                            reports.append(file_report)
                             lines = file.readlines()
-                            tell("{}".format(source_file_path), "info")
+                            file_report.tell("{}".format(source_file_path), Report.INFO)
                             latex.append(
                                 self.transform_page_to_latex(
-                                    lines, source_file_path, False
+                                    lines, source_file_path, False, file_report
                                 )
                             )
                 latex.append("\\clearpage\\newpage")
-        latex.append("\end{document}")
+        latex.append(r"\end{document}")
         latex = "\n".join(latex)
         target_file_path = self.output_file
-        write_file(latex, target_file_path)
+        write_file(latex, target_file_path, report)
 
-    def transform_page_to_latex(self, lines, filepath, abort_draft):
-        chunks = _parse(lines, filepath)
+    def transform_page_to_latex(self, lines, filepath, abort_draft, report):
+        chunks = _parse(lines, filepath, report)
         chunks = cast(chunks)
         chunks = arrange_assides(chunks)
 
@@ -143,7 +128,7 @@ class Builder:
         return latex
 
 
-def build_latex_yaml(build_file, base_path):
+def build_latex(build_file, base_path):
     with open(build_file) as file:
         for doc in load_all(file, Loader=SafeLoader):
             b = Builder(doc, base_path)
