@@ -11,11 +11,12 @@ from .chunks import HTMLChunk, MarkdownChunk, YAMLDataChunk
 from .code import Code
 from .figure import Figure
 from .hint import Hint
+from .hint2 import Hint2
 from .lines import Lines
 from .parse import ParserState, _parse
 from .table import Table
-from .tell import tell
 from .video import Video
+from .report import Report
 
 
 def random_id():
@@ -62,6 +63,8 @@ def cast(rawchunks):
                         chunks.append(Lines(raw, dictionary, page_variables))
                     elif yaml_type == "table":
                         chunks.append(Table(raw, dictionary, page_variables))
+                    elif yaml_type == "hint":
+                        chunks.append(Hint2(raw, dictionary, page_variables))
                     # TODO warn if unknown type
                 else:
                     data_chunk = YAMLDataChunk(raw, dictionary, page_variables)
@@ -71,9 +74,9 @@ def cast(rawchunks):
                         print(e)
                     chunks.append(data_chunk)
             else:
-                tell(
+                raw.report.tell(
                     "Something is wrong with the YAML section.",
-                    level="error",
+                    level=Report.ERROR,
                     chunk=raw,
                 )
         elif chunk_type == ParserState.HTML:
@@ -91,7 +94,10 @@ def arrange_assides(chunks):
             if current_main_chunk is not None:
                 current_main_chunk.asides.append(chunk)
             else:
-                tell("Aside chunk cannot be defined as first element.", level="warn")
+                chunk.raw_chunk.report.tell(
+                    "Aside chunk cannot be defined as first element.",
+                    level=Report.WARNING,
+                )
                 main_chunks.append(chunk)
         else:
             main_chunks.append(chunk)
